import { Component, OnInit } from '@angular/core';
import { NavController, MenuController, LoadingController, Loading, AlertController, NavParams } from 'ionic-angular';
import { Validators, FormGroup, FormBuilder } from "@angular/forms";

import { AuthService } from "../../services/auth-service";
import { PouchService } from "../../services/pouch-service";

@Component({
  	selector: 'page-login',
  	templateUrl: 'login.html'
})
export class LoginPage implements OnInit {
	
	loader: Loading;
	loginForm: FormGroup;

	constructor(
		public navCtrl: NavController,
		public menuCtrl: MenuController,
		public loadingCtrl: LoadingController,
		public alertCtrl: AlertController,
		public navParams: NavParams,
		public formBuilder: FormBuilder,
		public auth: AuthService,
		public pouch: PouchService
	) { 
		this.loginForm = this.formBuilder.group({
			host: ['http://localhost:8100', Validators.required],
			database: ['odoo', Validators.required],
			username: ['admin', Validators.required],
			password: ['admin', Validators.required],
		});
	}

	/**
	 *
	 */
	ionViewDidLoad() {
		this.menuCtrl.enable(false);
	}

	/**
	 *
	 */
	ngOnInit() {
		console.log('init');
	}
	
	/**
	 *
	 */
	signin(login): void {
		this.loader = this.loadingCtrl.create({
			content: "Identificando usuario, espere..."
		});
		this.loader.present();

		this.auth.initialize(login.host);
		this.auth.login(login.database, login.username, login.password).subscribe(response => {
			this.loader.dismiss();
			console.log(response);
		}, error => { 
			this.loader.dismiss();

			this.alertCtrl.create({
				title: 'Atención',
				message: 'No se puede conectar al servidor',
				buttons: [
					'Aceptar'
				]
			}).present();
		});
	}
}
