import { Injectable } from "@angular/core";
import { Observable } from "rxjs/Observable";
import { Observer } from "rxjs/Observer";
import PouchDB from "pouchdb";
import * as PouchFind from "pouchdb-find";

PouchDB.plugin(PouchFind);

@Injectable()
export class PouchService {

    pouchDB: any;

    constructor() {
        this.initialize();
    }

    /**
     *
     */
    private initialize(): void {
        this.pouchDB = new PouchDB("odoo", {
            auto_compaction: true
        });
        this.pouchDB.createIndex({
            index: {
                fields: ['type']
            }
        }).then(response => console.log(response)).catch(error => console.log(error));
    }

    /**
     *
     */
    save(data: any): Observable<any> {
        if (!data.type) {
            return Observable.throw("Error: Cannot save data without type");
        }

        return Observable.create((observer: Observer<any>) => {
            this.pouchDB.put(data).then(response => {
                observer.next(response);
                observer.complete();
            }).catch(error => observer.error(error));
        });
    }

    /**
     *
     */
    remove(data: any): Observable<any> {
        if (!data._id || !data._rev) {
            return Observable.throw("Error: Cannot remove data without id or rev");
        }

        return Observable.create((observer: Observer<any>) => {
            this.pouchDB.remove(data).then(response => {
                observer.next(response);
                observer.complete();
            }).catch(error => observer.error(error));
        });
    }

    /**
     *
     */
    get(data: any): Observable<any> {
        if (!data._id) {
            return Observable.throw("Error: Cannot get data without id");
        }

        return Observable.create((observer: Observer<any>) => {
            this.pouchDB.get(data._id).then(response => {
                observer.next(response);
                observer.complete();
            }).catch(error => observer.error(error));
        });

    }

    /**
     *
     */
    getAll(type: string): Observable<any> {
        return Observable.create((observer: Observer<any>) => {
            this.pouchDB.find({
                selector: {
                    name: {
                        $eq: type
                    }
                }
            }).then(response => {
                observer.next(response);
                observer.complete();
            }).catch(error => observer.error(error));
        });
    }
}
